==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/GitSourceRevisionFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitSourceRevisionFluent<A extends GitSourceRevisionFluent<A>> extends BaseFluent<A>{
  public GitSourceRevisionFluent() {
  }
  public GitSourceRevisionFluent(GitSourceRevision instance) {
    instance = (instance != null ? instance : new GitSourceRevision());

    if (instance != null) {
      this.withAuthor(instance.getAuthor());
      this.withCommit(instance.getCommit());
      this.withCommitter(instance.getCommitter());
      this.withMessage(instance.getMessage());
      this.withAuthor(instance.getAuthor());
      this.withCommit(instance.getCommit());
      this.withCommitter(instance.getCommitter());
      this.withMessage(instance.getMessage());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SourceControlUserBuilder author;
  private String commit;
  private SourceControlUserBuilder committer;
  private String message;
  private Map<String,Object> additionalProperties;
  public SourceControlUser buildAuthor() {
    return this.author!=null ?this.author.build():null;
  }
  public A withAuthor(SourceControlUser author) {
    _visitables.get("author").remove(this.author);
    if (author!=null){ this.author= new SourceControlUserBuilder(author); _visitables.get("author").add(this.author);} else { this.author = null; _visitables.get("author").remove(this.author); } return (A) this;
  }
  public boolean hasAuthor() {
    return this.author != null;
  }
  public A withNewAuthor(String email,String name) {
    return (A)withAuthor(new SourceControlUser(email, name));
  }
  public AuthorNested<A> withNewAuthor() {
    return new AuthorNested(null);
  }
  public AuthorNested<A> withNewAuthorLike(SourceControlUser item) {
    return new AuthorNested(item);
  }
  public AuthorNested<A> editAuthor() {
    return withNewAuthorLike(java.util.Optional.ofNullable(buildAuthor()).orElse(null));
  }
  public AuthorNested<A> editOrNewAuthor() {
    return withNewAuthorLike(java.util.Optional.ofNullable(buildAuthor()).orElse(new SourceControlUserBuilder().build()));
  }
  public AuthorNested<A> editOrNewAuthorLike(SourceControlUser item) {
    return withNewAuthorLike(java.util.Optional.ofNullable(buildAuthor()).orElse(item));
  }
  public String getCommit() {
    return this.commit;
  }
  public A withCommit(String commit) {
    this.commit=commit; return (A) this;
  }
  public boolean hasCommit() {
    return this.commit != null;
  }
  public SourceControlUser buildCommitter() {
    return this.committer!=null ?this.committer.build():null;
  }
  public A withCommitter(SourceControlUser committer) {
    _visitables.get("committer").remove(this.committer);
    if (committer!=null){ this.committer= new SourceControlUserBuilder(committer); _visitables.get("committer").add(this.committer);} else { this.committer = null; _visitables.get("committer").remove(this.committer); } return (A) this;
  }
  public boolean hasCommitter() {
    return this.committer != null;
  }
  public A withNewCommitter(String email,String name) {
    return (A)withCommitter(new SourceControlUser(email, name));
  }
  public CommitterNested<A> withNewCommitter() {
    return new CommitterNested(null);
  }
  public CommitterNested<A> withNewCommitterLike(SourceControlUser item) {
    return new CommitterNested(item);
  }
  public CommitterNested<A> editCommitter() {
    return withNewCommitterLike(java.util.Optional.ofNullable(buildCommitter()).orElse(null));
  }
  public CommitterNested<A> editOrNewCommitter() {
    return withNewCommitterLike(java.util.Optional.ofNullable(buildCommitter()).orElse(new SourceControlUserBuilder().build()));
  }
  public CommitterNested<A> editOrNewCommitterLike(SourceControlUser item) {
    return withNewCommitterLike(java.util.Optional.ofNullable(buildCommitter()).orElse(item));
  }
  public String getMessage() {
    return this.message;
  }
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  public boolean hasMessage() {
    return this.message != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitSourceRevisionFluent that = (GitSourceRevisionFluent) o;
    if (!java.util.Objects.equals(author, that.author)) return false;

    if (!java.util.Objects.equals(commit, that.commit)) return false;

    if (!java.util.Objects.equals(committer, that.committer)) return false;

    if (!java.util.Objects.equals(message, that.message)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(author,  commit,  committer,  message,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (author != null) { sb.append("author:"); sb.append(author + ","); }
    if (commit != null) { sb.append("commit:"); sb.append(commit + ","); }
    if (committer != null) { sb.append("committer:"); sb.append(committer + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AuthorNested<N> extends SourceControlUserFluent<AuthorNested<N>> implements Nested<N>{
    AuthorNested(SourceControlUser item) {
      this.builder = new SourceControlUserBuilder(this, item);
    }
    SourceControlUserBuilder builder;
    public N and() {
      return (N) GitSourceRevisionFluent.this.withAuthor(builder.build());
    }
    public N endAuthor() {
      return and();
    }
    
  }
  public class CommitterNested<N> extends SourceControlUserFluent<CommitterNested<N>> implements Nested<N>{
    CommitterNested(SourceControlUser item) {
      this.builder = new SourceControlUserBuilder(this, item);
    }
    SourceControlUserBuilder builder;
    public N and() {
      return (N) GitSourceRevisionFluent.this.withCommitter(builder.build());
    }
    public N endCommitter() {
      return and();
    }
    
  }
  
}

==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/GitSourceRevisionFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class GitSourceRevisionFluent<A extends GitSourceRevisionFluent<A>> extends BaseFluent<A>{
  public GitSourceRevisionFluent() {
  }
  
  public GitSourceRevisionFluent(GitSourceRevision instance) {
    this.copyInstance(instance);
  }
  private SourceControlUserBuilder author;
  private String commit;
  private SourceControlUserBuilder committer;
  private String message;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(GitSourceRevision instance) {
    instance = (instance != null ? instance : new GitSourceRevision());
  
    if (instance != null) {
        this.withAuthor(instance.getAuthor());
        this.withCommit(instance.getCommit());
        this.withCommitter(instance.getCommitter());
        this.withMessage(instance.getMessage());
        this.withAuthor(instance.getAuthor());
        this.withCommit(instance.getCommit());
        this.withCommitter(instance.getCommitter());
        this.withMessage(instance.getMessage());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public SourceControlUser buildAuthor() {
    return this.author!=null ?this.author.build():null;
  }
  
  public A withAuthor(SourceControlUser author) {
    _visitables.get("author").remove(this.author);
    if (author!=null){ this.author= new SourceControlUserBuilder(author); _visitables.get("author").add(this.author);} else { this.author = null; _visitables.get("author").remove(this.author); } return (A) this;
  }
  
  public boolean hasAuthor() {
    return this.author != null;
  }
  
  public A withNewAuthor(String email,String name) {
    return (A)withAuthor(new SourceControlUser(email, name));
  }
  
  public AuthorNested<A> withNewAuthor() {
    return new AuthorNested(null);
  }
  
  public AuthorNested<A> withNewAuthorLike(SourceControlUser item) {
    return new AuthorNested(item);
  }
  
  public AuthorNested<A> editAuthor() {
    return withNewAuthorLike(java.util.Optional.ofNullable(buildAuthor()).orElse(null));
  }
  
  public AuthorNested<A> editOrNewAuthor() {
    return withNewAuthorLike(java.util.Optional.ofNullable(buildAuthor()).orElse(new SourceControlUserBuilder().build()));
  }
  
  public AuthorNested<A> editOrNewAuthorLike(SourceControlUser item) {
    return withNewAuthorLike(java.util.Optional.ofNullable(buildAuthor()).orElse(item));
  }
  
  public String getCommit() {
    return this.commit;
  }
  
  public A withCommit(String commit) {
    this.commit=commit; return (A) this;
  }
  
  public boolean hasCommit() {
    return this.commit != null;
  }
  
  public SourceControlUser buildCommitter() {
    return this.committer!=null ?this.committer.build():null;
  }
  
  public A withCommitter(SourceControlUser committer) {
    _visitables.get("committer").remove(this.committer);
    if (committer!=null){ this.committer= new SourceControlUserBuilder(committer); _visitables.get("committer").add(this.committer);} else { this.committer = null; _visitables.get("committer").remove(this.committer); } return (A) this;
  }
  
  public boolean hasCommitter() {
    return this.committer != null;
  }
  
  public A withNewCommitter(String email,String name) {
    return (A)withCommitter(new SourceControlUser(email, name));
  }
  
  public CommitterNested<A> withNewCommitter() {
    return new CommitterNested(null);
  }
  
  public CommitterNested<A> withNewCommitterLike(SourceControlUser item) {
    return new CommitterNested(item);
  }
  
  public CommitterNested<A> editCommitter() {
    return withNewCommitterLike(java.util.Optional.ofNullable(buildCommitter()).orElse(null));
  }
  
  public CommitterNested<A> editOrNewCommitter() {
    return withNewCommitterLike(java.util.Optional.ofNullable(buildCommitter()).orElse(new SourceControlUserBuilder().build()));
  }
  
  public CommitterNested<A> editOrNewCommitterLike(SourceControlUser item) {
    return withNewCommitterLike(java.util.Optional.ofNullable(buildCommitter()).orElse(item));
  }
  
  public String getMessage() {
    return this.message;
  }
  
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  
  public boolean hasMessage() {
    return this.message != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitSourceRevisionFluent that = (GitSourceRevisionFluent) o;
    if (!java.util.Objects.equals(author, that.author)) return false;
  
    if (!java.util.Objects.equals(commit, that.commit)) return false;
  
    if (!java.util.Objects.equals(committer, that.committer)) return false;
  
    if (!java.util.Objects.equals(message, that.message)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(author,  commit,  committer,  message,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (author != null) { sb.append("author:"); sb.append(author + ","); }
    if (commit != null) { sb.append("commit:"); sb.append(commit + ","); }
    if (committer != null) { sb.append("committer:"); sb.append(committer + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AuthorNested<N> extends SourceControlUserFluent<AuthorNested<N>> implements Nested<N>{
    AuthorNested(SourceControlUser item) {
      this.builder = new SourceControlUserBuilder(this, item);
    }
    SourceControlUserBuilder builder;
    
    public N and() {
      return (N) GitSourceRevisionFluent.this.withAuthor(builder.build());
    }
    
    public N endAuthor() {
      return and();
    }
    
  
  }
  public class CommitterNested<N> extends SourceControlUserFluent<CommitterNested<N>> implements Nested<N>{
    CommitterNested(SourceControlUser item) {
      this.builder = new SourceControlUserBuilder(this, item);
    }
    SourceControlUserBuilder builder;
    
    public N and() {
      return (N) GitSourceRevisionFluent.this.withCommitter(builder.build());
    }
    
    public N endCommitter() {
      return and();
    }
    
  
  }

}
